/* REXX-Script for OS/2 2.x version of KRIBER */

'@ECHO OFF'

/*
#Header of kriber.pas / kriber.c
#
#******************************************************************************
#*                                                                            *
#*   Program  KRIBER              Version 1.0       (January 1991)            *
#*   ===============                                                          *
#*                                                                            *
#*   Author:   Roland Bialek, Institut fuer Kristallografie und Petrografie   *
#*             ETH-Zentrum, CH-8092 Zuerich, Switzerland                      *
#*                                                                            *
#*   an interactive PASCAL program to                                         *
#*    - calculate distances and angles                                        *
#*    - generate input files for the programs DLS-76 and LOADAT (XRS-82)      *
#*    - calculate coordination sequences and loop configurations              *
#*                                                                            *
#*   Program Installation and Modification                                    *
#*   -------------------------------------                                    *
#*  The program is written in standard PASCAL and has been implemented and    *
#*  fully tested on a CYBER 855 running under NOS/VE 1.5.2. It has also been  *
#*  used successfully on a MicroVax II machine under VMS 5.2                  *
#*                                                                            *
#*  There is only one extension to the standard PASCAL used: The identifiers  *
#*  contain the underscore (_) and the dollar sign ($). If your PASCAL        *
#*  does not have this extension, you can remove these two signs with your    *
#*  editor.                                                                   *
#*                                                                            *
#*  Input:  The program runs interactively.                                   *
#*                                                                            *
#*  Output: The output is written to the terminal screen (longest line is     *
#*          80 columns wide).                                                 *
#*                                                                            *
#*  Files:  SYMDAT, STRUDAT, DISTDAT and COSEQ are input files, DLSINPUT,     *
#*          LOADATINPUT, LIST and STRUDATNEW are output files.                *
#*                                                                            *
#*  Arrays: Following constants can be changed in the constant declaration    *
#*          part:                                                             *
#*          maxanzahlatomlagen    :   maximum number of atom positions        *
#*          maxanzahlbindungen    :   maximum number of bonds per atom        *
#*          maxanzahlsymeqkarten  :   maximum number of symeq cards           *
#*          maxindepwinkel        :   maximum number of independent angles    *
#*          maxindepdistanzen     :   maximum number of independent distances *
#*          maxanzahlgegwinkel    :   maximum number of prescribed angles     *
#*          maxanzahlgegdistanzen :   maximum number of prescribed distances  *
#*          maxanzahldistanzen    :   maximum number of calculated distances  *
#*                                                                            *
#******************************************************************************
*/

/* Where symdat, strudat, distdat, coseq and kriber.x are */
xdir = 'c:\os2local\kriber'

/* Executable */
KRIBERX = xdir'\kriber.exe'

/* Add REXX utilities */
CALL RxFuncAdd 'SysFileTree', 'RexxUtil', 'SysFileTree'

kif.0=4
kif.1='symdat '
kif.2='strudat'
kif.3='distdat'
kif.4='coseq  '

lnl.0=4
lnl.1=0
lnl.2=0
lnl.3=0
lnl.4=0

SIGNAL ON HALT NAME Interrupt

DO i = 1 to kif.0

 CALL SysFileTree kif.i, 'datei', 'FO'

 IF datei.0 = 0
  THEN DO

   'COPY 'xdir'\'kif.i' 'kif.i' > NUL 2>&1'

   IF rc <> 0
    THEN DO

     SAY 'kriber: can''t copy 'xdir'\'STRIP( kif.i )' to working directory.'
     XStatus = 1
     SIGNAL UNLNS

    END

   lnl.i = 1
   SAY 'kriber: 'kif.i' = 'xdir'\'kif.i

  END
  ELSE DO

   lnl.i=0
   SAY 'kriber: 'kif.i' = ./'kif.i

  END

END /* DO */


SAY 'Running 'KRIBERX
KRIBERX
Xstatus=rc


UNLNS:

DO i = 1 to kif.0

 IF lnl.i = 1
  THEN DO

   'DEL 'kif.i' > NUL 2>&1'
   lnl.i = 0

  END

END /* DO */

CALL SysFileTree 'list', 'datei', 'F'

IF datei.0 = 1
 THEN DO

  PARSE VALUE datei.1 WITH '           'size'  '

  IF size = 0
   THEN
    'DEL list > NUL 2>&1'

 END /* IF */

EXIT(Xstatus)


Interrupt:
  SAY 'Interrupt signal received.'
  Xstatus=1
  SIGNAL UNLNS
